# UCSC

This module is used to interact with the UCSC genome browser.
Currently there is only the BLAT API which is implemented.

| Module | Description |
|--------|-------------|
|[`blat`](./ucsc/blat.md)| Performs a BLAT sequence search on a provided database |
